Actors - 'Coney Island' Scripted TV & Video | Backstage
Description: all characters based on Phantom of the Opera characters, English, French, Cockney and Persian accents a plus.
Keywords: Auditions | Casting calls | Open casting calls | Casting call | Open casting call

- Like us on Facebook
- Follow us on Twitter

- Find Jobs
- Find Talent
- My Account
  - Edit Profile
  - Messages
  - My Dashboard
  - Job History
  - Account Settings
  - Help
  - Logout
- Job History
- JOIN
- Login
- Help

### Instant Access

This casting/job notice is still under review by Backstage's editors. However, you can apply right away! Scams and inappropriate content will be promptly removed.

TV & Video: Scripted TV & Video

Production: 'Coney Island' (See all 3 roles)

# Actors (Supporting)

- Scripted TV & Video
- Nonunion
- Paid

- Share:
- Like on Facebook
- Tweet
- Email
- Copy Link

Production Details

Casting the TV pilot, "Coney Island." Project description: "Pilot for a tv drama series based on characters from Phantom of the Opera, centering around a Freak Show run by Meg & Th...more

Get more details on 'Coney Island', including pay, union details, full description, rehearsal & production dates & locations, script sides, other roles, and more.

Seeking

Males & Females, ages 18+, All Ethnicities

Role Description

Actors: (Supporting) all characters based on Phantom of the Opera characters, English, French, Cockney and Persian accents a plus.

Auditions

January 4th in Petersburg, VA. Sign up or Log In to apply.